@@ -1,10 +1,19 @@
-#' Confidence Intervals for Standardized Regression Coefficients
+#' Confidence Intervals for
+#' Standardized Regression Coefficients
 #'
 #' @author Ivan Jacob Agaloos Pesigan
 #'
-#' @return Returns a matrix.
+#' @return Returns a matrix of
+#'   standardized regression slopes,
+#'   standard errors,
+#'   test statistics,
+#'   p-values,
+#'   and
+#'   confidence intervals.
 #'
 #' @param object Object of class `betadelta`.
+#' @param alpha Numeric vector.
+#'   Significance level.
 #'
 #' @family Beta Delta Functions
 #' @keywords betaDelta ci internal
@@ -19,12 +28,12 @@
   )
   return(
     .CIWald(
-      object$beta,
+      object$est,
       se = sqrt(diag(object$vcov)),
       theta = 0,
       alpha = alpha,
       z = FALSE,
-      df = object$df
+      df = object$lm_process$df
     )
   )
 }
